capture log close
log using wflec-add-data-russia1-controls, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s1manual

//  WF lectures: adding - russia 1, adding controls

local pgm wflec-add-data-russia1
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data

use wf-russia01, replace
datasignature confirm

//  #2 create controls for demographic variables

gen female = gender - 1
label var female "Female?"
label def female 0 0_male 1 1_female
label val female female
note female: based on gender / `tag'
tab gender female, miss

gen male = 1 - female
label var male "Male?"
label def male 1 1_male 0 0_female
label val male male
note male: based on gender / `tag'
tab gender male, miss

recode marstat (1 2 3 4=1) (5=0), gen(married)
label def married 1 1_married 0 0_never
label val married married
label var married "Ever married?"
note married: recoding of marstat / married includes married, ///
widowed, divorced, separated / `tag'

tab marstat married, miss

recode edlevel (1 2 3 4 5=0) (6 7=1) (99=.n), gen(hidegree)
label var hidegree "Any higher education?"
label def hidegree 0 0_not 1 1_high_ed
label val hidegree hidegree
note hidegree: recode of edlevel / `tag'
tab edlevel hidegree, miss

recode empstat (1 7=1) (2 3 5 6 8 9 10=0) (98=.d) (99=.n), gen(fulltime)
label def fulltime 1 1_fulltime 0 0_not
label val fulltime fulltime
label var fulltime "Ever worked full time?"
note fulltime: recoding of empstat; includes fulltime & retired / `tag'
tab empstat fulltime, miss

//  #3 check new variables

codebook female-fulltime, compact

//  #4 cleanup and save

local savename wflec-russia02.dta
sort id
quietly compress
label data "`savename' | Russia add controls | `dte'"
note: `savename' / `tag'
datasignature set, reset
save `savename', replace

* verify data that was saved
use `savename', clear
datasignature confirm
notes
codebook, compact
capture noisily cf _all using wf-russia01

log close
exit
