capture log close
log using wflec-analysis-locals-specifications, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: analysis - local for model specification

local pgm wflec-analysis-locals-specifications
local dte 2017-06-19
local who Scott Long
local tag "`pgm'.do `who' `dte'"

//  #1 load data

use wf-tenure, clear
datasignature confirm
keep if sampleis

//  #2 nested models predicting tenure - with locals

//  define groups of variables

local Vtime "year yearsq"      // time in rank
local Vdept "select prestige"  // characteristics of departments
local Vprod "articles"         // research productivity

//  #2a = baseline gender only model

logit tenure female, nolog

//  #2b + time

logit tenure female `Vtime', nolog

//  #2c + department

logit tenure female `Vtime' `Vdept', nolog

//  #2d + productivity

logit tenure female `Vtime' `Vdept' `Vprod', nolog

//#3 nested models another way

local Vtime "year yearsq"      // time in rank
local Vdept "select prestige"  // characteristics of departments
local Vprod "articles"         // research productivity

local model1 female
local model2 `model1' `Vtime'
local model3 `model2' `Vdept'
local model4 `model3' `Vprod'

foreach number in 1 2 3 4 {
    logit tenure `model`number''
}

//#3 nested models a third way

local Vfem  "female"
local Vtime "year yearsq"      // time in rank
local Vdept "select prestige"  // characteristics of departments
local Vprod "articles"         // research productivity

foreach varset in Vfem Vtime Vdept Vprod {
    local rhsvars "`rhsvars' ``varset''"
    logit tenure `rhsvars'
}

log close
exit
