capture log close
log using wflec-auto-loops, replace text
version 14
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: automation - loops

global pgm wflec-auto-loops$ver
global dte 2017-06-18
global who Scott Long
global tag "$pgm.do $who $dte"

//  Example 1: displaying names
foreach ivarnm in var1 var2 var3 {
    display "ivarnm is `ivarnm'"
}

//  Example 2: displaying values

foreach ivalue in 1 72 3 {
    display "ivalue is `ivalue'"
}

//  Example 3: series of summary commands

use wf-lfp, clear
nmlab lfp k5 k618 age wc hc lwg inc
foreach varnm in lfp k5 k618 age wc hc lwg inc {
    sum `varnm'
}

//  Example 4: echoing the commands

foreach varnm in lfp k5 k618 age wc hc lwg inc {
    display _new ". sum `varnm'"
    sum `varnm'
}

//  support for later commands

use wf-ordwarm, clear
tab warm, miss

* biary indicators
gen warm_lt2 = warm<2 if !missing(warm)
gen warm_lt3 = warm<3 if !missing(warm)
gen warm_lt4 = warm<4 if !missing(warm)

* loop does the same thing
use wf-ordwarm, clear
capture drop warm_lt*
foreach cutpt in 2 3 4 {
    gen warm_lt`cutpt' = warm<`cutpt' if !missing(warm)
    *tab warm warm_lt`cutpt', miss
}

//  Example 5: series of binary logits

local rhsvars "yr89 male white age ed prst"
local lhsvars "warm_lt2 warm_lt3 warm_lt4"
foreach lhsvar in `lhsvars' {
    di _new ". tab `lhsvar'"
               tab `lhsvar'
    di _new ". logit `lhsvar' `rhsvars'"
               logit `lhsvar' `rhsvars'
}

//  Example 6:  loop to create lhs variable names

local rhsvars "yr89 male white age ed prst"
foreach cutpt in 2 3 4 {
    local lhsvar "warm_lt`cutpt'"
    di _new ". tab   `lhsvar"
               tab   `lhsvar'
    di _new ". logit `lhsvar' `rhsvars'"
               logit `lhsvar' `rhsvars'
}

//  Example 7: create binary indicators

use wf-ordwarm, clear
tab warm, miss

* biary indicators
gen warm_lt2 = warm<2 if !missing(warm)
gen warm_lt3 = warm<3 if !missing(warm)
gen warm_lt4 = warm<4 if !missing(warm)

* loop does the same thing
use wf-ordwarm, clear
capture drop warm_lt*
foreach cutpt in 2 3 4 {
    gen warm_lt`cutpt' = warm<`cutpt' if !missing(warm)
    tab warm warm_lt`cutpt', miss
}

//  Example 8: list variable name and labels

local varlabel : variable label warm
di "varlabel for warm:"
di "`varlabel'"

* place the label in column 12:
local varnm "warm"
di "`varnm'" _col(12) "`varlabel'"

* loop through multiple variables
local rhsvars "yr89 male white age ed prst"
local lhsvar "warm"
foreach varnm in `lhsvars' `rhsvars' {
    local varlabel : variable label `varnm'
    di "`varnm'" _col(12) "`varlabel'"
}

//  Example 8R1: list variable name and labels - add counter

local rhsvars "yr89 male white age ed prst"
local lhsvar "warm"
local counter = 0
foreach varnm in `lhsvars' `rhsvars' {
    local counter = `counter' + 1
    local varlabel : variable label `varnm'
    di "`counter'. `varnm'" _col(12) "`varlabel'"
}

//  Example 9: add variable name to variable labels

use wf-ordwarm, clear
local varname  "warm"
local varlabel : variable label `varname'
di "varname>  `varname'"
di "varlabel> `varlabel'"
label var `varname' "`varname': `varlabel'"
local varlabel : variable label `varname'
di "varlabel>  `varlabel'"
tab `varname'

* In a loop:
local vars " warm yr89 male white age ed prst"
foreach var in `vars' {
    local varlabel : variable label `var'
    label var `varname' "`varname': `varlabel'"
}
nmlab `varvars'

//  Example 10: create interaction variables with labels

use wf-ordwarm, clear
foreach varname in yr89 white age ed prst {
    gen  maleX`varname' = male*`varname'
    label var maleX`varname'  "male*`varname'"
    note maleX`varname': $tag.
}
codebook maleX*, compact

* make labels with variable labels from the source variables:
foreach varname in yr89 white age ed prst {
    local varlabel : variable label `varname'
    gen  maleX`varname'V2 = male*`varname'
    label var maleX`varname'V2 "male*`varlabel'"
}
codebook maleX*V2, compact

//  Example 11: recoding variables

* dichotomize using if statements
use wf-loops, clear
local sdvars "sdneighb sdsocial sdchild sdfriend sdwork sdmarry"
foreach varname of varlist `sdvars' {
    gen       B`varname' = `varname'
    label var B`varname' "`varname': (1,2)=0 (3,4)=1"
    replace   B`varname' = 0 if `varname'==1 | `varname'==2
    replace   B`varname' = 1 if `varname'==3 | `varname'==4
}

* to show commands
use wf-loops, clear
local sdvars "sdneighb sdsocial sdchild sdfriend sdwork sdmarry"
foreach varname of varlist `sdvars' {
    gen       B`varname' = `varname'
* why thye funny quotes?
di `". gen       B`varname' = `varname'"'
    label var B`varname' "`varname': (1,2)=0 (3,4)=1"
di `". label var B`varname' "`varname': (1,2)=0 (3,4)=1""'
    replace   B`varname' = 0 if `varname'==1 | `varname'==2
di `". replace   B`varname' = 0 if `varname'==1 | `varname'==2"'
    replace   B`varname' = 1 if `varname'==3 | `varname'==4
di `". replace   B`varname' = 1 if `varname'==3 | `varname'==4"'
}

* take the log of multiple variables:
foreach varname in incp1 incp2 incp3 incp4 incp5 {
    gen       ln`varname' = ln(`varname'+.5) if `varname'<.
    label var ln`varname' "Log(`varname'+.5)"
    note ln`varname': $tag
}
nmlab ln*

//  forvalues =============================================================

//  Example 12: listing 1 to 10

forvalue ivalue = 1/10 {
    display "ivalue = `ivalue'"
}

//  Example 12: compute 1st through 5th root

* no loop
use wf-lfp, clear
gen inc_root1 = inc^(1/1)
label var inc_root1 "income^(1/1)"
gen inc_root2 = inc^(1/2)
label var inc_root2 "income^(1/2)"

* using a loop
use wf-lfp, clear
forvalues iroot = 1(1)5 {
    gen       inc_root`iroot' = inc^(1/`iroot')
    label var inc_root`iroot' "income^(1/`iroot')"
    note      inc_root`iroot': $tag
}
nmlab inc*
note inc*


log close
exit
