capture log close
log using wflec-dual-data03-regvars, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - data 03 create regression vars

local pgm wflec-dual-data03-regvars
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

local srcdata wflec-dual-data01
local savdata wflec-dual-data02

use `srcdata', clear
datasignature confirm

//  #3 momwarm outcome

recode v4 (1=1) (2=2) (3=.n) (4=3) (5=4) (8=.a) (9=.b), gen(momwarm)
label var momwarm "Working mom can have warm relations"
label def momwarm 1 1StrPos 2 2Pos 3 3Neg ///
    4 4StrNeg .a a_Unsure .b b_Refused .n n_Neutral
label val momwarm momwarm
note momwarm : from v4 3=neutral in source coded .n \ `tag'
tab momwarm v4, miss

//  #2 categorical regressors

clonevar sex = v200
clonevar age = v201
clonevar marital = v202
clonevar denom = v288
clonevar motherwork = v55
clonevar educ = v205
clonevar numchild = v69
clonevar fincome = v250
clonevar empstat = v239

gen female = sex - 1
label var female "Female"
label def female 0 Male 1 Female
label val female female
note female: recode sex \ `tag'
tab sex female, miss

gen male = 1 - female
label var male "Male"
label def male 1 Male 0 Female
label val male male
note male: recode female \ `tag'
tab sex male, miss

recode marital (1 2 3 4=1) (5=0) (9=.), gen(married)
label def married 1 Married 0 No
label val married married
label var married "Has been married"
note married: recode marital \ married includes married, ///
widowed, divorced, separated. NA & refused is missing \ `tag'
tab marital married, miss

recode educ (0 1 2 3=0) (4 5=1) (9=.), gen(highered)
label var highered "Beyond high school"
label def highered 0 No 1 HigherEd
label val highered highered
note highered: recode educ \ `tag'
tab educ highered, miss

recode empstat (1 7=1) (2 3 5 6 8 9 10=0) (98=.d) (99=.n), gen(fulltime)
label def fulltime 1 Fulltime 0 No
label val fulltime fulltime
label var fulltime "Has worked full time"
note fulltime: recode empstat; includes fulltime & retired \ `tag'
tab empstat fulltime, miss

recode denom (990=0) (100 200 300 500 600 700 800=1) ///
    (998=.d) (999=.n), gen(religion)
label def religion 1 Religious 0 None, replace
label val religion religion
label var religion "Has religious affiliation"
note religion: recode denom \ `tag'
tab religion religion, miss

recode motherwork (1=1) (2=0) (8=.d) (9=.n), gen(momworks)
label def momworks 1 Works 0 No, replace
label val momworks momworks
label var momworks "R's mother worked for pay"
note momworks: recoding of motherwork \ `tag'
tab motherwork momworks, miss

recode numchild (0=1) (1/14=0) (98=.d) (99=.n), gen(kidsnone)
label def kidsnone 1 None 0 Kids, replace
label val kidsnone kidsnone
label var kidsnone "No children"
note kidsnone: recoding of numchild \ `tag'
tab numchild kidsnone, miss

recode numchild (0/2=0) (3/14=1) (98=.d) (99=.n), gen(kidsthree)
label def kidsthree 1 "Three+" 0 "0-2", replace
label val kidsthree kidsthree
label var kidsthree "3 or more children"
note kidsthree: recoding of numchild; \ `tag'
tab numchild kidsthree, miss

//  #3 continuous regressors

kdensity fincome // check extreme values
graph export `pgm'-fincome.png, replace
tab fincome if fincome>100000
recode fincome (999997=.r) (999998=.d) (999999=.n), gen(faminc)
label var faminc "Family income"
kdensity faminc
graph export `pgm'-faminc.png, replace
note faminc: recode fincome. Refusals, DKs, NA coded as missing \ `tag'

gen logfaminc = ln(faminc)
label var logfaminc "Log of family income"
note logfaminc: natural log family income (faminc) \ `tag'
sum fincome logfaminc
kdensity logfaminc
graph export `pgm'-logfaminc.png, replace

label var age "Age"
label var momworks "Rs mom worked"

//  #4 check variables and add metadata

codebook female-logfaminc, compact // rhs variables
notes female-logfaminc

label data "`savdata'.dta | ISSP Russia 2002 Working Women | `dte'"
notes: `savdata'.dta | `tag' | add regressors
datasignature set, reset
save `savdata', replace
notes _dta

//  #5 check the new dataset

use `savdata', clear
datasignature confirm

* examine changes from soruce dataset
capture noisily cf _all using `srcdata'.dta, all

log close //
exit
label var female "Female"
label var married "Has been married"
label var logfaminc "Log of family income"
label var highered "Some college"
label var fulltime "Has worked fulltime"
label var kidsnone "No children"
label var religion "No religion"
label var kidsthree "3 or more children"
