capture log close
log using wflec-replication-split, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: replication - split sample

global pgm wflec-replication-split
global dte 2017-06-20
global who Scott Long
global tag "$pgm.do $who $dte"

//  #1 load data

use hrs-gme-analysis2.dta, clear

//  #2 randomly split sample three ways

lab def Lsample 1 Explore 2 Verify
qui sum hhid
local nhalf = round(r(N)/2,1)

local set 1
set seed 193211 // same
    gen double _random = runiform()
    lab var _random "uniform random"
    sort _random
    gen sample`set' = 2
    replace sample`set' = 1 in 1/`nhalf'
    lab var sample`set' "set `set' random subsample indicator"
    lab val sample`set' sample
    drop _random

local set 2
set seed 19321 // fem v wight
    gen double _random = runiform()
    lab var _random "uniform random"
    sort _random
    gen sample`set' = 2
    replace sample`set' = 1 in 1/`nhalf'
    lab var sample`set' "set `set' random subsample indicator"
    lab val sample`set' sample
    drop _random

local set 3
set seed 192 // two fewer
    gen double _random = runiform()
    lab var _random "uniform random"
    sort _random
    gen sample`set' = 2
    replace sample`set' = 1 in 1/`nhalf'
    lab var sample`set' "set `set' random subsample indicator"
    lab val sample`set' sample
    drop _random

//  #3 estimate multiple models

local rhs "age agesq bmi female height weight hsdegree white"

foreach set in 1 2 3 {

    stepwise, pe(.05): logit diabetes age agesq bmi female ///
        height weight hsdegree white if sample`set'==1
    est store explore`set'

    stepwise, pe(.05): logit diabetes age agesq bmi female ///
        height weight hsdegree white if sample`set'==2
    est store verify`set'

    estimates table explore`set' verify`set', ///
        eform p b(%9.3f) p(%9.2f) title(Randomization set `set')

}

    est restore verify2
    est store theory
    est store stepwise

//  #4 summary results

set linesize 100
estimates table explore1 verify1 explore2 verify2 explore3 verify3, ///
        eform b(%8.3f) p(%8.2f) title(Randomization set `set') ///
        stat(N bic)

*stars
estimates table explore1 verify1 explore2 verify2 explore3 verify3, ///
        eform b(%6.3f) title(Randomization set `set') /// p(%8.2f)
        stat(N bic) ///
        star(.10 .05 .01) stfmt(%6.1f) varwidth(7) model(7)

estimates table theory stepwise, ///
        eform b(%8.3f) p(%8.2f) title(Randomization set `set') ///
        stat(N bic)

estimates table theory stepwise, ///
        eform b(%8.3f) title(Randomization set `set') /// p(%8.2f)
        stat(N bic) star(.10 .05 .01)

set linesize 80

log close
exit

local explorenms : colnames e(b)
local verifynms : colnames e(b)


bfit logit diabetes `rhs' if sample==1


