capture log close
log using wflec-var-commands, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: commands for variables

local pgm wflec-var-commands
local dte 2017-06-18
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 examine var lables

use wf-lfp, clear
local lhsvar lfp
local rhsvars k5 k618 age wc hc lwg inc
codebook `lhsvar' `rhsvars', compact
nmlab `lhsvar' `rhsvars'

use wf-names, clear
tabulate tcfam, missing
lab var tcfam ///
"Question 43: How important is it to you to turn to the family for support?"
tabulate tcfam, missing

//  #2 temporary labels

use wf-acjob, clear
scatter job phd
graph export `pgm'-labels-original.png, replace

label var job "Prestige of job"
label var phd "Prestige of PhD"
scatter job phd
graph export `pgm'-labels-temporary.png, replace

//  #3 note for variable

use wf-acpub, clear
gen pubtrunc = pub
replace pubtrunc = 20 if pubtrunc>20 & !missing(pubtrunc)
label var pubtrunc "pub truncated at 20"
note pubtrunc: pubs>20 to 20 / `tag'
note pubtrunc

note pubtrunc: Earlier analyses (pubreg04a.do 2006-09-20) ///
showed that cases with a  large number of articles were ///
outliers. pubreg04b.do 2006-09-21 examined different ///
transformations of pub9 and found that truncation at 20 ///
was most effective at removing the outliers. / `tag'
note pubtrunc

codebook pubtrunc, notes

//  #4 value labels - unclear value labels

use wf-names, clear
tabulate wc_v1 k5
tabulate wc_v2 k5
tabulate wc_v3 k5

//  #5 value labels too long

* for illustration, create alternative definitions of labels
label define sd_v1 1 "Definitely Willing" 2 "Probably Willing" ///
    3 "Probably Unwilling" 4 "Definitely Unwilling"
label define sd_v2 1 1Definite 2 2Probably 3 3ProbNot 4 4DefNot
label define sd_v3 1 Definite 2 Probably 3 ProbNot 4 DefNot

* assign labels to variables
clonevar sdchild_v1 = sdchild
label val sdchild_v1 sd_v1
clonevar sdchild_v2 = sdchild
label val sdchild_v2 sd_v2
clonevar sdchild_v3 = sdchild
label val sdchild_v3 sd_v3

* list each version of the labels
labelbook sd_v1 sd_v2 sd_v3

* tabulate with version 1 of labels
tabulate female sdchild_v1
tabulate female sdchild_v1, nolabel

* tabulate with version 2 of labels
tabulate female sdchild_v2
tabulate female sdchild_v2, nolabel

* tabulate with version 3 of labels
tabulate female sdchild_v3
tabulate female sdchild_v3, nolabel

labelbook sd_v1 sd_v2

//  #5 value labels - adding numbers

* adding values to labels the hard way
label define defnot 1 "1Definite" 2 "2Probably" 3 "3ProbNot" 4 "4DefNot"
label val sdchild defnot
tabulate sdchild

* adding values with numlabel - start with the labels that follow
label drop defnot
label define defnot 1 "Definite" 2 "Probably" 3 "ProbNot" 4 "DefNot"

* make a copy
label copy defnot defnotN

* let numlabel add the values
numlabel defnotN, mask(#_) add
label val sdchild defnotN
tabulate sdchild

* returning to the original labels
label val sdchild defnot
tabulate sdchild

* and back again
label val sdchild defnotN
tabulate sdchild

* removing numbers from labels
numlabel defnotN, mask(#_) remove
label val sdchild defnotN
tabulate sdchild

* adding numbers such as 1. to labels
numlabel defnotN, mask(#. ) add
label val sdchild defnotN
tabulate sdchild

//  #6 value lables - danger or shared labels

label define twocat 0 No 1 Yes
label value lfp female twocat  // I assign 2 vars at once
tabulate female lfp

* changte label for female
label define twocat 0 Male 1 Female, modify
tabulate female lfp

//  #7 example

use wf-lfp, clear
gen wages = exp(lwg) if !missing(lwg)
label var wages "Wife's estiamted wages"
note wages: `tag'

gen anycollege = .
replace anycollege = 1 if hc==1 | wc==1
replace anycollege = 0 if hc==0 & wc==0
label var anycollege "Wife or husband college?"
label def anycollege 0 NoCollege 1 AnyCollege
label val anycollege anycollege
note anycollege: `tag'

* compare labels for college variables
tab1 wc hc anycollege, miss

* use same labels for all college variable
label def Lnewcollege 0 NoCollege   1 SomeCollege
label val anycollege Lnewcollege
label val wc         Lnewcollege
label val hc         Lnewcollege
tab1 wc hc anycollege, miss

* check new variables
describe wage anycollege
notes wage anycollege

log close
exit
